@@ -185,6 +185,12 @@ class LoadMaster(HttpClient):
         virt_serv = self.build_virtual_service(service)
         return virt_serv
 
+    def get_all_objects(self):
+        virtual_services = self.get_virtual_services()
+        for service in virtual_services:
+            service.real_servers = service.get_real_servers()
+        return virtual_services
+
     def build_virtual_service(self, service):
         """Create a VirtualService instance with standard defaults"""
         is_sub_vs = True if int(service.get('MasterVSID', 0)) != 0 else False
@@ -401,7 +407,7 @@ class KempBaseObjectModel(object):
     # blacklist attributes that shouldn't be pushed to the loadmaster.
     _API_IGNORE = (
         "ip_address", "endpoint", "rsindex", "vsindex", "index", "status",
-        "subvs_data", "subvs_entries",
+        "subvs_data", "subvs_entries", "real_servers",
     )
 
     def __repr__(self):
